aboutsummaryrefslogtreecommitdiffstats
path: root/csit/prepare-csit.sh
diff options
context:
space:
mode:
authorefiacor <fiachra.corcoran@est.tech>2022-12-07 10:56:27 +0000
committerefiacor <fiachra.corcoran@est.tech>2022-12-07 15:59:59 +0000
commitbda6aeaa60607ab4fe5af508156019d7bd5c0ce4 (patch)
tree24bae3847c1139ba9aed95ce286277202aae9a93 /csit/prepare-csit.sh
parentb37d32a39c7096e39fc389f15d150e8c2b8c54c2 (diff)
[DMAAP-DR] Remove AAF/TLS phase 1
Signed-off-by: efiacor <fiachra.corcoran@est.tech> Change-Id: Ifeae01dd8e7f0a737d8b74594a8061ae3d4ea647 Issue-ID: DMAAP-1642
Diffstat (limited to 'csit/prepare-csit.sh')
-rwxr-xr-xcsit/prepare-csit.sh22
1 files changed, 8 insertions, 14 deletions
diff --git a/csit/prepare-csit.sh b/csit/prepare-csit.sh
index 109cdb49..22a102db 100755
--- a/csit/prepare-csit.sh
+++ b/csit/prepare-csit.sh
@@ -18,31 +18,25 @@
#
if [ -z "$WORKSPACE" ]; then
+ # shellcheck disable=SC2155
export WORKSPACE=`git rev-parse --show-toplevel`
fi
+# shellcheck disable=SC2034
TESTPLANDIR=${WORKSPACE}/${TESTPLAN}
# Assume that if ROBOT_VENV is set and virtualenv with system site packages can be activated,
# ci-management/jjb/integration/include-raw-integration-install-robotframework.sh has already
# been executed
if [ -f ${WORKSPACE}/env.properties ]; then
source ${WORKSPACE}/env.properties
fi
-if [ -f ${ROBOT_VENV}/bin/activate ]; then
- source ${ROBOT_VENV}/bin/activate
+if [ -f ${ROBOT3_VENV}/bin/activate ]; then
+ source ${ROBOT3_VENV}/bin/activate
else
- rm -rf /tmp/ci-management
rm -f ${WORKSPACE}/env.properties
- cd /tmp
- git clone "https://gerrit.onap.org/r/ci-management"
- source /tmp/ci-management/jjb/integration/include-raw-integration-install-robotframework.sh
+ source ${WORKSPACE}/install-robotframework.sh
fi
-# install eteutils
-mkdir -p ${ROBOT_VENV}/src/onap
-rm -rf ${ROBOT_VENV}/src/onap/testsuite
-pip install --upgrade --extra-index-url="https://nexus3.onap.org/repository/PyPi.staging/simple" 'robotframework-onap==0.5.1.*' --pre
-
+pip install --upgrade --extra-index-url="https://nexus3.onap.org/repository/PyPi.staging/simple" 'robotframework-onap==7.0.2.*' --pre
pip freeze
@@ -18,31 +18,25 @@
TESTPLANDIR=${WORKSPACE}/${TESTPLAN}
-# Assume that if ROBOT_VENV is set and virtualenv with system site packages can be activated,
-# ci-management/jjb/integration/include-raw-integration-install-robotframework.sh has already
-# been executed
+# Assume that if ROBOT3_VENV is set and virtualenv with system site packages can be activated,
+# and install-robotframework.sh has already been executed
if [ -f ${WORKSPACE}/env.properties ]; then
source ${WORKSPACE}/env.properties